@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import abc
 import urllib
 
 from oslo_utils import uuidutils
@@ -20,174 +21,31 @@ from oslo_utils import uuidutils
 from oslo_serialization import jsonutils as json
 from tempest.lib.common import rest_client
 
-from zaqar_tempest_plugin.api_schema.response.v1 \
-    import queues as v1schema
 from zaqar_tempest_plugin.api_schema.response.v1_1 \
     import queues as v11schema
 from zaqar_tempest_plugin.api_schema.response.v2 \
     import queues as v2schema
 
 
-class MessagingClient(rest_client.RestClient):
+class MessagingClient(rest_client.RestClient, metaclass=abc.ABCMeta):
 
     def __init__(self, auth_provider, service, region, **kwargs):
         super(MessagingClient, self).__init__(
             auth_provider, service, region, **kwargs)
 
-        self.version = '1'
         self.uri_prefix = 'v{0}'.format(self.version)
 
         client_id = uuidutils.generate_uuid(dashed=False)
         self.headers = {'Client-ID': client_id}
 
 
-class V1MessagingClient(MessagingClient):
-    def __init__(self, auth_provider, service, region, **kwargs):
-        super(V1MessagingClient, self).__init__(
-            auth_provider, service, region, **kwargs)
-
-        self.version = '1'
-
-    def list_queues(self):
-        uri = '{0}/queues'.format(self.uri_prefix)
-        resp, body = self.get(uri)
-
-        if resp['status'] != '204':
-            body = json.loads(body)
-            self.validate_response(v1schema.list_queues, resp, body)
-        return resp, body
-
-    def create_queue(self, queue_name):
-        uri = '{0}/queues/{1}'.format(self.uri_prefix, queue_name)
-        resp, body = self.put(uri, body=None)
-        self.expected_success(201, resp.status)
-        return resp, body
-
-    def show_queue(self, queue_name):
-        uri = '{0}/queues/{1}'.format(self.uri_prefix, queue_name)
-        resp, body = self.get(uri)
-        self.expected_success(204, resp.status)
-        return resp, body
-
-    def head_queue(self, queue_name):
-        uri = '{0}/queues/{1}'.format(self.uri_prefix, queue_name)
-        resp, body = self.head(uri)
-        self.expected_success(204, resp.status)
-        return resp, body
-
-    def delete_queue(self, queue_name):
-        uri = '{0}/queues/{1}'.format(self.uri_prefix, queue_name)
-        resp, body = self.delete(uri)
-        self.expected_success(204, resp.status)
-        return resp, body
-
-    def show_queue_stats(self, queue_name):
-        uri = '{0}/queues/{1}/stats'.format(self.uri_prefix, queue_name)
-        resp, body = self.get(uri)
-        body = json.loads(body)
-        self.validate_response(v1schema.queue_stats, resp, body)
-        return resp, body
-
-    def show_queue_metadata(self, queue_name):
-        uri = '{0}/queues/{1}/metadata'.format(self.uri_prefix, queue_name)
-        resp, body = self.get(uri)
-        self.expected_success(200, resp.status)
-        body = json.loads(body)
-        return resp, body
-
-    def set_queue_metadata(self, queue_name, rbody):
-        uri = '{0}/queues/{1}/metadata'.format(self.uri_prefix, queue_name)
-        resp, body = self.put(uri, body=json.dumps(rbody))
-        self.expected_success(204, resp.status)
-        return resp, body
-
-    def post_messages(self, queue_name, rbody):
-        uri = '{0}/queues/{1}/messages'.format(self.uri_prefix, queue_name)
-        resp, body = self.post(uri, body=json.dumps(rbody),
-                               extra_headers=True,
-                               headers=self.headers)
-
-        body = json.loads(body)
-        self.validate_response(v1schema.post_messages, resp, body)
-        return resp, body
-
-    def list_messages(self, queue_name):
-        uri = '{0}/queues/{1}/messages?echo=True'.format(self.uri_prefix,
-                                                         queue_name)
-        resp, body = self.get(uri, extra_headers=True, headers=self.headers)
-
-        if resp['status'] != '204':
-            body = json.loads(body)
-            self.validate_response(v1schema.list_messages, resp, body)
-
-        return resp, body
-
-    def show_single_message(self, message_uri):
-        resp, body = self.get(message_uri, extra_headers=True,
-                              headers=self.headers)
-        if resp['status'] != '204':
-            body = json.loads(body)
-            self.validate_response(v1schema.get_single_message, resp,
-                                   body)
-        return resp, body
-
-    def show_multiple_messages(self, message_uri):
-        resp, body = self.get(message_uri, extra_headers=True,
-                              headers=self.headers)
-
-        if resp['status'] != '204':
-            body = json.loads(body)
-            self.validate_response(v1schema.get_multiple_messages,
-                                   resp,
-                                   body)
-
-        return resp, body
-
-    def delete_messages(self, message_uri):
-        resp, body = self.delete(message_uri)
-        self.expected_success(204, resp.status)
-        return resp, body
-
-    def post_claims(self, queue_name, rbody, url_params=False):
-        uri = '{0}/queues/{1}/claims'.format(self.uri_prefix, queue_name)
-        if url_params:
-            uri += '?%s' % urllib.parse.urlencode(url_params)
-
-        resp, body = self.post(uri, body=json.dumps(rbody),
-                               extra_headers=True,
-                               headers=self.headers)
-
-        body = json.loads(body)
-        self.validate_response(v1schema.claim_messages, resp, body)
-        return resp, body
-
-    def query_claim(self, claim_uri):
-        resp, body = self.get(claim_uri)
-
-        if resp['status'] != '204':
-            body = json.loads(body)
-            self.validate_response(v1schema.query_claim, resp, body)
-        return resp, body
-
-    def update_claim(self, claim_uri, rbody):
-        resp, body = self.patch(claim_uri, body=json.dumps(rbody))
-        self.expected_success(204, resp.status)
-        return resp, body
-
-    def delete_claim(self, claim_uri):
-        resp, body = self.delete(claim_uri)
-        self.expected_success(204, resp.status)
-        return resp, body
-
-
 class V11MessagingClient(MessagingClient):
+    version = '1.1'
+
     def __init__(self, auth_provider, service, region, **kwargs):
         super(V11MessagingClient, self).__init__(
             auth_provider, service, region, **kwargs)
 
-        self.version = '1.1'
-        self.uri_prefix = 'v{0}'.format(self.version)
-
     def list_queues(self):
         uri = '{0}/queues'.format(self.uri_prefix)
         resp, body = self.get(uri, headers=self.headers)
@@ -317,13 +175,12 @@ class V11MessagingClient(MessagingClient):
 
 
 class V2MessagingClient(MessagingClient):
+    version = '2'
+
     def __init__(self, auth_provider, service, region, **kwargs):
         super(V2MessagingClient, self).__init__(
             auth_provider, service, region, **kwargs)
 
-        self.version = '2'
-        self.uri_prefix = 'v{0}'.format(self.version)
-
     def list_queues(self, url_params=False):
         uri = '{0}/queues'.format(self.uri_prefix)
         if url_params:
